@@ -1,4 +1,4 @@
-from perfect_information_game.utils import ActiveGame as GameClass
+from perfect_information_game.games import Chess as GameClass
 from perfect_information_game.learning import train_from_config
 
 
