@@ -1,6 +1,7 @@
 import pickle
 from perfect_information_game.ui import PygameUI
-from perfect_information_game.utils import get_training_path, ActiveGame as GameClass
+from perfect_information_game.utils import get_training_path
+from perfect_information_game.games import Chess as GameClass
 
 
 def view_game(path):
